# HybridFusion

Define how the query's hybrid fusion operation should be performed.

## Enum

* `FUSION_TYPE_RANKED` (value: `'FUSION_TYPE_RANKED'`)

* `FUSION_TYPE_RELATIVE_SCORE` (value: `'FUSION_TYPE_RELATIVE_SCORE'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


